# introduction
'wmath' is a simple mathematical package designed by a bored undergraduate who wants to review math and python at the same time.
## features:
- wmath use a class called '**Meta**' to manage the global meta information, which is not allowed to be instantiated. 
- wmath has its own class **Fraction** as one of its basic data types. 
- param '**_new**' is a bool data, included in many methods in wmath, that decides whether to return a brand-new data or apply change on {self}, 
- '**_deepcopy**' is another common bool parameter, which decides whether deepcopy or just copy. in most cases, **_deepcopy** is True default.   
## modules
- meta.py ------ manage the global meta information. 
- number_theory.py ------ handling number theory problems in math. 
- fraction.py ------ the operation in fraction. 
- paradigm.py ------ the basic class of paradigm classes. 
- polynomial.py ------ the related problems in polynomial. 
- matrix.py ------ the problems related to matrix. 
- cross.py ------ define cross functions that involve several classes.  
## [reference](./REFERENCE.md)